AsyncQueueReceiver

Struct AsyncQueueReceiver 

pub struct AsyncQueueReceiver<T>(/* private fields */);
An asynchronous queue receiver. Can be used to receive data from an AsyncQueueSender. Use channel to create.

For a purely blocking queue, see Queue.

Implementations

Source

impl<T> AsyncQueueReceiver<T>
where T: Send + Sized + 'static,

pub fn messages_waiting(&self) -> UBaseType_t

Returns the number of messages waiting in the queue.

pub fn receive_blocking( &mut self, max_wait: Duration, ) -> Result<T, FreeRtosError>

Waits for an item to be available on the queue.

Returns an item if available and an error if no item is available after max_wait.

pub async fn receive(&mut self) -> T

Asynchronous version of receive_blocking.

This function stays pending until the queue has received an item.