pub struct BlockingToAsyncQueueTaskBuilder<T> { /* private fields */ }Expand description
Builder for a task that can receive items from a blocking Queue and send them to an
asynchronous queue.
Implementations
Sourceimpl<T> BlockingToAsyncQueueTaskBuilder<T>
impl<T> BlockingToAsyncQueueTaskBuilder<T>
Sourcepub fn new(name: &'static CStr, queue: Queue<T>, capacity: UBaseType_t) -> Self
pub fn new(name: &'static CStr, queue: Queue<T>, capacity: UBaseType_t) -> Self
Creates a new queue bridge task builder.
Sourcepub fn priority(self, priority: TaskPriority) -> Self
pub fn priority(self, priority: TaskPriority) -> Self
Sets the priority of the FreeRTOS task.
Sourcepub fn stack_size(self, stack_size: StackType_t) -> Self
pub fn stack_size(self, stack_size: StackType_t) -> Self
Sets the stack size of the FreeRTOS task.
Sourcepub fn create(self) -> Result<AsyncQueueReceiver<T>, FreeRtosError>
pub fn create(self) -> Result<AsyncQueueReceiver<T>, FreeRtosError>
Creates the task and returns a receiver to receive items from the blocking queue in an asynchronous manner.